pub(crate) enum EndGatewayChunkPreparation {
Ready(Vec<ChunkPos>),
SearchPath(Vec<ChunkPos>),
}Expand description
Initial chunk preparation needed before resolving an End gateway transition.
Variants
Ready(Vec<ChunkPos>)
Requested chunks are enough to calculate the transition after they load.
SearchPath(Vec<ChunkPos>)
Requested chunks only cover vanilla’s tentative outer-island search.